@@ -50,12 +50,19 @@ function(model,
         pred[["fitted"]] <- pred[[ w[1L] ]]
     }
     
-    # obs-x-(ncol(data)+2+nlevels(outcome)) data.frame of predictions
-    structure(pred,
-              class = c("prediction", "data.frame"), 
-              row.names = seq_len(nrow(pred)),
+    # variance(s) of average predictions
+    vc <- NA_real_
+    
+    # output
+    structure(pred, 
+              class = c("prediction", "data.frame"),
               at = if (is.null(at)) at else at_specification,
-              model.class = class(model),
               type = NA_character_,
-              category = category)
+              call = if ("call" %in% names(model)) model[["call"]] else NULL,
+              model_class = class(model),
+              row.names = seq_len(nrow(pred)),
+              vcov = vc,
+              jacobian = NULL,
+              category = category,
+              weighted = FALSE)
 }
